Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(930)

Unified Diff: chrome/gpu/arc_gpu_video_decode_accelerator.h

Issue 2919193002: ArcBridge: Rename VideoAcceleratorService to VideoDecodeAccelerator. (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/gpu/arc_gpu_video_decode_accelerator.h
diff --git a/chrome/gpu/arc_gpu_video_decode_accelerator.h b/chrome/gpu/arc_gpu_video_decode_accelerator.h
index 917be53847734bed561f64ed9d01ff3a661d850d..f376b2038c236e47997b0d3b4259526e35e0d36b 100644
--- a/chrome/gpu/arc_gpu_video_decode_accelerator.h
+++ b/chrome/gpu/arc_gpu_video_decode_accelerator.h
@@ -12,7 +12,7 @@
#include "base/callback.h"
#include "base/threading/thread_checker.h"
-#include "chrome/gpu/arc_video_accelerator.h"
+#include "chrome/gpu/arc_video_decode_accelerator.h"
#include "gpu/command_buffer/service/gpu_preferences.h"
#include "media/video/video_decode_accelerator.h"
@@ -24,7 +24,7 @@ namespace arc {
// implementation of media::VideoDecodeAccelerator. It also returns the decoded
// frames back to the ARC side.
class ArcGpuVideoDecodeAccelerator
- : public ArcVideoAccelerator,
+ : public ArcVideoDecodeAccelerator,
public media::VideoDecodeAccelerator::Client,
public base::SupportsWeakPtr<ArcGpuVideoDecodeAccelerator> {
public:
@@ -32,10 +32,10 @@ class ArcGpuVideoDecodeAccelerator
const gpu::GpuPreferences& gpu_preferences);
~ArcGpuVideoDecodeAccelerator() override;
- // Implementation of the ArcVideoAccelerator interface.
- ArcVideoAccelerator::Result Initialize(
+ // Implementation of the ArcVideoDecodeAccelerator interface.
+ ArcVideoDecodeAccelerator::Result Initialize(
const Config& config,
- ArcVideoAccelerator::Client* client) override;
+ ArcVideoDecodeAccelerator::Client* client) override;
void SetNumberOfOutputBuffers(size_t number) override;
void BindSharedMemory(PortType port,
uint32_t index,
@@ -107,9 +107,9 @@ class ArcGpuVideoDecodeAccelerator
};
// The helper method to simplify reporting of the status returned to UMA.
- ArcVideoAccelerator::Result InitializeTask(
+ ArcVideoDecodeAccelerator::Result InitializeTask(
const Config& config,
- ArcVideoAccelerator::Client* client);
+ ArcVideoDecodeAccelerator::Client* client);
// Helper function to validate |port| and |index|.
bool ValidatePortAndIndex(PortType port, uint32_t index) const;
@@ -143,7 +143,7 @@ class ArcGpuVideoDecodeAccelerator
// It's safe to use the pointer here, the life cycle of the |arc_client_|
// is longer than this ArcGpuVideoDecodeAccelerator.
- ArcVideoAccelerator::Client* arc_client_;
+ ArcVideoDecodeAccelerator::Client* arc_client_;
// The next ID for the bitstream buffer, started from 0.
int32_t next_bitstream_buffer_id_;

Powered by Google App Engine
This is Rietveld 408576698